@@ -1,5 +1,4 @@
 import logging
-import os
 import sys
 import inject
 from mfcloud.util import txtimeout
@@ -77,14 +76,12 @@ class DNSServerFactory(server.DNSServerFactory):
 
 
 def dump_resolv_conf(dns_server_ip):
-    if os.path.exists('/etc/resolv.conf'):
-        ns_line = 'nameserver %s' % dns_server_ip
-        with open('/etc/resolv.conf', 'r') as f:
-            contents = f.read()
-            print contents
-        if not ns_line in contents:
-            with open('/etc/resolv.conf', 'w') as f:
-                f.write('%s\n%s' % (ns_line, contents))
+    ns_line = 'nameserver %s' % dns_server_ip
+    with open('/etc/resolv.conf', 'r') as f:
+        contents = f.read()
+    if not ns_line in contents:
+        with open('/etc/resolv.conf', 'w') as f:
+            f.write('%s\n%s' % (ns_line, contents))
 
 
 def listen_dns(dns_prefix, dns_server_ip, dns_port):
@@ -129,7 +126,7 @@ def entry_point():
         # Configure a shared injector.
         inject.configure(my_config)
 
-        dump_resolv_conf(dns_server_ip)
+        #dump_resolv_conf(dns_server_ip)
         listen_dns(dns_prefix, dns_server_ip, dns_port)
 
 
