@@ -1,12 +1,8 @@
 import json
 import logging
 import sys
-import time
 import uuid
-from autobahn.twisted.wamp import ApplicationSession
-from autobahn.twisted.websocket import WampWebSocketClientProtocol, WampWebSocketClientFactory
-import inject
-from mfcloud.remote import Client, Task, ApiError
+
 import re
 import os
 import pprintpp
@@ -32,6 +28,8 @@ class ApiRpcClient(object):
 
     @inlineCallbacks
     def _remote_exec(self, task_name, on_result, *args, **kwargs):
+        from mfcloud.remote import Client, Task
+
         client = Client(host=self.host)
         try:
             yield client.connect()
@@ -128,6 +126,9 @@ class ApiRpcClient(object):
 
     def on_print_list_result(self, data):
 
+        if not data:
+            return 
+
         x = PrettyTable(["Application name", "Web", "status", "services"], hrules=ALL)
         for app in data:
 
@@ -359,9 +360,10 @@ class ApiRpcClient(object):
 
         def on_result(result):
 
-            os.system("docker run -i -t --dns=%(dns-server)s --dns-search=%(dns-suffix)s --volumes-from=%(container)s %(image)s %(command)s" % {
+            os.system("docker run -i -t -v %(hosts_vol)s --volumes-from=%(container)s %(image)s %(command)s" % {
                 'container': '%s.%s' % (service, app),
                 'image': result['image'],
+                'hosts_vol': '%s:/etc/hosts' % result['hosts_path'],
                 'dns-server': result['dns-server'],
                 'dns-suffix': '%s.%s' % (app, result['dns-suffix']),
                 'command': command
@@ -472,7 +474,6 @@ def populate_client_parser(subparsers):
 
 
 import argparse
-from cmd import Cmd
 
 from mfcloud import metadata
 
